@@ -52,21 +52,21 @@ public:
 
     ~FileBrowserProxyModel() override;
 
-    QString filterText() const;
+    [[nodiscard]] QString filterText() const;
 
-    int filterRating() const;
+    [[nodiscard]] int filterRating() const;
 
-    bool sortedAscending() const;
+    [[nodiscard]] bool sortedAscending() const;
 
-    MediaPlayListProxyModel* playList() const;
+    [[nodiscard]] MediaPlayListProxyModel* playList() const;
 
     void setSourceModel(QAbstractItemModel *sourceModel) override;
 
 public Q_SLOTS:
 
-    void enqueueToPlayList(QModelIndex rootIndex);
+    void enqueueToPlayList(const QModelIndex &rootIndex);
 
-    void replaceAndPlayOfPlayList(QModelIndex rootIndex);
+    void replaceAndPlayOfPlayList(const QModelIndex &rootIndex);
 
     void enqueue(const DataTypes::MusicDataType &newEntry,
                  const QString &newEntryTitle,
@@ -105,7 +105,7 @@ private Q_SLOTS:
 
 private:
 
-    void genericEnqueueToPlayList(QModelIndex rootIndex,
+    void genericEnqueueToPlayList(const QModelIndex &rootIndex,
                                   ElisaUtils::PlayListEnqueueMode enqueueMode,
                                   ElisaUtils::PlayListEnqueueTriggerPlay triggerPlay);
 
